      subroutine fvoxxx(fo,vc,fvo)
c
c This subroutine computes an off-shell fermion wavefunction from a
c flowing-OUT external fermion and a vector boson.
c
c
c input:
c       complex fo(6)          : flow-out fermion                   <fo|
c       complex vc(6)          : input    vector                      v
c
c output:
c       complex fvo(6)         : off-shell fermion             <fo,v,f'|
c
      implicit none
      double complex fo(6),vc(6),fvo(6),d
      double precision pf(4),pf2

      double precision rZero, rOne
      parameter( rZero = 0.0d0, rOne = 1.0d0 )
      double complex cImag, cZero
      parameter( cImag = ( 0.0d0, 1.0d0 ), cZero = ( 0.0d0, 0.0d0 ) )


      fvo(5) = fo(5)+vc(5)
      fvo(6) = fo(6)+vc(6)

      pf(1) = dble( fvo(5))
      pf(2) = dble( fvo(6))
      pf(3) = dimag(fvo(6))
      pf(4) = dimag(fvo(5))
      pf2 = pf(1)**2-(pf(2)**2+pf(3)**2+pf(4)**2)


      d = -rOne/dcmplx( pf2, 0.d0)
c

        fvo(1)=(-((pf(1) + pf(4))*
     -     (fo(2)*(vc(2) + cImag*vc(3)) + 
     -       fo(1)*(-vc(1) + vc(4)))) + 
     -  (pf(2) + cImag*pf(3))*
     -   (fo(1)*(-vc(2) + cImag*vc(3)) + 
     -     fo(2)*(vc(1) + vc(4))))*d


        fvo(2)=(-((pf(2) - cImag*pf(3))*
     -     (fo(2)*(vc(2) + cImag*vc(3)) + 
     -       fo(1)*(-vc(1) + vc(4)))) + 
     -  (pf(1) - pf(4))*
     -   (fo(1)*(-vc(2) + cImag*vc(3)) + 
     -     fo(2)*(vc(1) + vc(4))))*d


        fvo(3)=((pf(2) + cImag*pf(3))*
     -   (fo(3)*(-vc(2) + cImag*vc(3)) + 
     -     fo(4)*(-vc(1) + vc(4))) + 
     -  (pf(1) - pf(4))*
     -   (fo(4)*(vc(2) + cImag*vc(3)) + 
     -     fo(3)*(vc(1) + vc(4))))*d


        fvo(4)=((pf(1) + pf(4))*
     -   (fo(3)*(vc(2) - cImag*vc(3)) + 
     -     fo(4)*(vc(1) - vc(4))) + 
     -  (-pf(2) + cImag*pf(3))*
     -   (fo(4)*(vc(2) + cImag*vc(3)) + 
     -     fo(3)*(vc(1) + vc(4))))*d

      end
